@@ -1,4 +1,3 @@
-
 ##  ............................................................................
 ##  line breaks                                                             ####
 # not inserting line breaks
@@ -98,3 +97,17 @@ call(
   {{ x }},
   {{ y }} := 3, f(bk)
 )
+
+call({{
+  #
+  1
+}})
+
+call({{
+  #
+}})
+
+
+{{
+  #
+}}
